==> aiowmi-0.1.5.tar.gz: aiowmi-0.1.5/aiowmi/ndr/class_part.py <==
import struct
from .heap import Heap
from .encoded_string import EncodedString
from .qualifier_set import QualifierSet
from .properties import Properties


class ClassPart:

    HEADER = '<LBLL'
    HEADER_SZ = struct.calcsize(HEADER)

    DIRIVATION_LIST = '<L'
    DIRIVATION_LIST_SZ = struct.calcsize(DIRIVATION_LIST)

    properties: Properties

    @classmethod
    def from_data(cls, data, offset):
        keep = offset

        # ClassHeader
        self = cls()
        (
            encoding_length,
            reserved,
            self.class_name_ref,
            self.nd_value_table_length,
        ) = struct.unpack_from(cls.HEADER, data, offset=offset)
        offset += cls.HEADER_SZ

        # DerivationList
        (
            enc_length,
        ) = struct.unpack_from(cls.DIRIVATION_LIST, data, offset=offset)
        end = offset + enc_length
        start = offset + cls.DIRIVATION_LIST_SZ

        self.class_name_encoding = data[start: end]
        offset += enc_length

        # QualifierSet
        self.qualifier_set, offset = QualifierSet.from_data(data, offset)

        self.properties, offset = Properties.from_data(data, offset)

        start = offset
        offset += self.nd_value_table_length
        self.nd_value_table = data[start: offset]

        # ClassHeap
        self.class_heap, offset = Heap.from_data(data, offset)

        garbage_size = encoding_length - (offset - keep)
        self.garbage = data[offset: offset+garbage_size]
        offset += garbage_size

        self.qualifier_set.load(self.class_heap)
        self.properties.load(self.class_heap, self.nd_value_table)

        return self, offset

    def get_name(self):
        if self.class_name_ref == 0xffffffff:
            return 'None'

        heap = self.class_heap
        name, offset = EncodedString.from_data(heap, self.class_name_ref)

        names = [name]
        dlist = self.class_name_encoding
        offset, end = 0, len(dlist)
        while offset < end:
            super_class, offset = EncodedString.from_data(dlist, offset)
            names.append(super_class)

        return ':'.join(names)

==> aiowmi-0.1.6.tar.gz: aiowmi-0.1.6/aiowmi/ndr/class_part.py <==
import struct
from .heap import Heap
from .encoded_string import EncodedString
from .qualifier_set import QualifierSet
from .properties import Properties


class ClassPart:

    HEADER = '<LBLL'
    HEADER_SZ = struct.calcsize(HEADER)

    DIRIVATION_LIST = '<L'
    DIRIVATION_LIST_SZ = struct.calcsize(DIRIVATION_LIST)

    properties: Properties

    @classmethod
    def from_data(cls, data, offset):
        keep = offset

        # ClassHeader
        self = cls()
        (
            encoding_length,
            reserved,
            self.class_name_ref,
            self.nd_value_table_length,
        ) = struct.unpack_from(cls.HEADER, data, offset=offset)
        offset += cls.HEADER_SZ

        # DerivationList
        (
            enc_length,
        ) = struct.unpack_from(cls.DIRIVATION_LIST, data, offset=offset)
        end = offset + enc_length
        start = offset + cls.DIRIVATION_LIST_SZ

        self.class_name_encoding = data[start: end]
        offset += enc_length

        # QualifierSet
        self.qualifier_set, offset = QualifierSet.from_data(data, offset)

        '''
        \x01\x00\x00\x00r\x00\x00\x00x\x00\x00\x00\x03\x00\x00\x00\x00\xaa\x00\x00\x80\x00Win32_OperatingSystem\x00\x00Singleton\x00\x00CIMWin32\x00\x00SupportsUpdate\x00\x00Locale\x00\x00UUID\x00\x00{8502C4DE-

        '''

        self.properties, offset = Properties.from_data(data, offset)

        start = offset
        offset += self.nd_value_table_length
        self.nd_value_table = data[start: offset]

        # ClassHeap
        self.class_heap, offset = Heap.from_data(data, offset)

        garbage_size = encoding_length - (offset - keep)
        self.garbage = data[offset: offset+garbage_size]
        offset += garbage_size

        self.qualifier_set.load(self.class_heap)
        self.properties.load(self.class_heap, self.nd_value_table)

        return self, offset

    def get_name(self):
        if self.class_name_ref == 0xffffffff:
            return 'None'

        heap = self.class_heap
        name, offset = EncodedString.from_data(heap, self.class_name_ref)

        names = [name]
        dlist = self.class_name_encoding
        offset, end = 0, len(dlist)
        while offset < end:
            super_class, offset = EncodedString.from_data(dlist, offset)
            names.append(super_class)

        return ':'.join(names)
